@@ -5,3 +5,6 @@ from sqldiff.meta.teradata_meta import get_meta
 from sqldiff.comp.compare import compare, ColumnsComparisonResult, KeyColumnComparisonResult
 
 from sqldiff.relation.relation_manager import get_relations
+
+# launch relation registering
+from sqldiff.relation import relation_register
